Change in osmo-ci[master]: OBS: use nightly script to build 2021q1 feed

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

osmith gerrit-no-reply at lists.osmocom.org
Tue May 18 07:35:15 UTC 2021


osmith has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-ci/+/24256 )


Change subject: OBS: use nightly script to build 2021q1 feed
......................................................................

OBS: use nightly script to build 2021q1 feed

Use the nightly script instead of latest, so all packages get
upgraded when upgrading osmocom-2021q1.

Related: SYS#5370
Change-Id: If8de585652997aae1edb586c948c181f564f6994
---
M scripts/osmocom-latest-packages.sh
M scripts/osmocom-nightly-packages.sh
M scripts/osmocom-packages-docker.sh
3 files changed, 14 insertions(+), 5 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-ci refs/changes/56/24256/1

diff --git a/scripts/osmocom-latest-packages.sh b/scripts/osmocom-latest-packages.sh
index c5c19c4..bbdc5a1 100755
--- a/scripts/osmocom-latest-packages.sh
+++ b/scripts/osmocom-latest-packages.sh
@@ -5,15 +5,14 @@
 # * PROJ: the OBS namespace to upload to (e.g. "network:osmocom:latest")
 # * FEED:
 #   * "latest": use latest tagged release (default)
-#   * other (e.g. "2021q1"): use last commit of branch of same name, exit with
-#     error if it does not exist
+#   * other: use last commit of branch of same name, exit with error if it does
+#     not exist
 # * PACKAGES: set to a space-separated list of packages to skip all others
 . "$(dirname "$0")/common.sh"
 . "$(dirname "$0")/common-obs.sh"
 
 # Values for FEED env var. Adjust FEEDS_ALL in common-obs when changing.
 FEEDS="
-  2021q1
   latest
 "
 
diff --git a/scripts/osmocom-nightly-packages.sh b/scripts/osmocom-nightly-packages.sh
index b9a56a3..cd50c7d 100755
--- a/scripts/osmocom-nightly-packages.sh
+++ b/scripts/osmocom-nightly-packages.sh
@@ -7,12 +7,15 @@
 # * FEED: controls the source branch that is used:
 #   * "nightly": use "master" branch (default)
 #   * "next": use "next" branch if it exists, otherwise use "master" branch
+#   * other (e.g. "2021q1"): use last commit of branch of same name, exit with
+#     error if it does not exist
 # * PACKAGES: set to a space-separated list of packages to skip all others
 . "$(dirname "$0")/common.sh"
 . "$(dirname "$0")/common-obs.sh"
 
 # Values for FEED env var. Adjust FEEDS_ALL in common-obs when changing.
 FEEDS="
+  2021q1
   next
   nightly
 "
@@ -61,6 +64,13 @@
     url="$(osmo_git_clone_url "$name")"
   fi
 
+  if [ -z "$branch" ]; then
+    case "$FEED" in
+    nightly|next) ;;
+    *) branch="$FEED" ;;  # e.g. 2021q1
+    esac
+  fi
+
   cd "$REPO"
 
   if [ -n "$branch" ] ; then
diff --git a/scripts/osmocom-packages-docker.sh b/scripts/osmocom-packages-docker.sh
index 4465d20..a7a804b 100755
--- a/scripts/osmocom-packages-docker.sh
+++ b/scripts/osmocom-packages-docker.sh
@@ -19,8 +19,8 @@
 	SCRIPT="osmocom-$FEED-packages.sh"
 	;;
 *)
-	# "2021q1" etc, osmocom-latest.sh verifies and uses $FEED
-	SCRIPT="osmocom-latest-packages.sh"
+	# "2021q1" etc, osmocom-nightly-packages.sh verifies and uses $FEED
+	SCRIPT="osmocom-nightly-packages.sh"
 	;;
 esac
 

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/24256
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: If8de585652997aae1edb586c948c181f564f6994
Gerrit-Change-Number: 24256
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith at sysmocom.de>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20210518/47e76199/attachment.htm>


More information about the gerrit-log mailing list